@@ -250,7 +250,9 @@ class Elastic(DataLayer):
             return
 
     def is_empty(self, resource):
-        return self.es.count({'type': resource}) == 0
+        args = self._es_args(resource)
+        res = self.es.count({'query': {'match_all': {}}}, **args)
+        return res.get('count', 0) == 0
 
     def _parse_hits(self, hits, resource):
         """Parse hits response into documents."""
@@ -289,4 +291,3 @@ class Elastic(DataLayer):
             if isinstance(v, ObjectId):
                 doc[k] = str(v)
         return doc
-    
\ No newline at end of file
